function [skew test se pval] = BaiNgTest(x)

% function [s t] = BaiNgTest(x)
% 
%  INPUT:  x = (Tx1) data vector
% 
% OUTPUT:  skew = coefficient of skewness of x
%          test = standard normally distributed test statistic H_{0}: s = 0
%                 Bai and Ng (JBES, 2005), Theorem 2 on pg.51
T=length(x);
skew=skewness(x);
mu=mean(x);
m3 = (1/T)*sum((x-mu).^3);
moms=[(x-mu).^3  x-mu]; % see eq. (3) in Bai and Ng 2005 JBES
gamma=nwest(moms);

a=[1 -3*var(x)]; % alpha defined below eq. (4) in BN
se = sqrt(((a*gamma*a')/(std(x)^6)));
test=skew*sqrt(T/((a*gamma*a')/(std(x)^6))); % see limiting dist. on top of pg. 51 BN 2005 JBES
pval = cdf('Normal',test,0,1); % testing for deepness (i.e., negative skewness)
